@@ -194,6 +194,7 @@ eog_job_thumbnail_run (EogJobThumbnail *job)
 {
 	gchar *orig_width, *orig_height;
 	gint width, height;
+	GdkPixbuf *pixbuf;
 
 	g_return_if_fail (EOG_IS_JOB_THUMBNAIL (job));
 
@@ -213,8 +214,10 @@ eog_job_thumbnail_run (EogJobThumbnail *job)
 	orig_width = g_strdup (gdk_pixbuf_get_option (job->thumbnail, "tEXt::Thumb::Image::Width"));
 	orig_height = g_strdup (gdk_pixbuf_get_option (job->thumbnail, "tEXt::Thumb::Image::Height"));
 
-	eog_thumbnail_fit_to_size (&job->thumbnail, EOG_LIST_STORE_THUMB_SIZE);
-	eog_thumbnail_add_frame (&job->thumbnail);
+	pixbuf = eog_thumbnail_fit_to_size (job->thumbnail, EOG_LIST_STORE_THUMB_SIZE);
+	g_object_unref (job->thumbnail);
+	job->thumbnail = eog_thumbnail_add_frame (pixbuf);
+	g_object_unref (pixbuf);
 
 	if (orig_width) {
 		sscanf (orig_width, "%i", &width);
@@ -266,7 +269,7 @@ eog_job_load_class_init (EogJobLoadClass *class)
 }
 
 EogJob *
-eog_job_load_new (EogImage *image)
+eog_job_load_new (EogImage *image, EogImageData data)
 {
 	EogJobLoad *job;
 
@@ -275,6 +278,7 @@ eog_job_load_new (EogImage *image)
 	if (image) {
 		job->image = g_object_ref (image);
 	}
+	job->data = data;
 
 	return EOG_JOB (job);
 }
@@ -290,7 +294,7 @@ eog_job_load_run (EogJobLoad *job)
 	}
 
 	eog_image_load (EOG_IMAGE (job->image),
-			EOG_IMAGE_DATA_ALL,
+			job->data,
 			EOG_JOB (job),
 			&EOG_JOB (job)->error);
 
@@ -356,7 +360,7 @@ filter_files (GSList *files, GList **file_list, GList **error_list)
 				   don't set the GFileType. */
 				if (G_UNLIKELY (type == G_FILE_TYPE_UNKNOWN)) {
 					const gchar *ctype;
-			
+
 					ctype = g_file_info_get_content_type (file_info);
 
 					/* If the content type is supported
