@@ -58,7 +58,8 @@ typedef enum {
 #define EOG_JPEG_MARKER_APP2	0xE2
 #define EOG_JPEG_MARKER_APP14	0xED
 
-#define IS_FINISHED(priv) (priv->exif_chunk != NULL && \
+#define IS_FINISHED(priv) (priv->state == EMR_READ  && \
+                           priv->exif_chunk != NULL && \
                            priv->icc_chunk  != NULL && \
                            priv->iptc_chunk != NULL && \
                            priv->xmp_chunk  != NULL)
@@ -67,14 +68,14 @@ struct _EogMetadataReaderJpgPrivate {
 	EogMetadataReaderState  state;
 
 	/* data fields */
-	gpointer exif_chunk;
 	guint    exif_len;
+	gpointer exif_chunk;
 
 	gpointer iptc_chunk;
 	guint	 iptc_len;
 
-	gpointer icc_chunk;
 	guint icc_len;
+	gpointer icc_chunk;
 
 	gpointer xmp_chunk;
 	guint xmp_len;
